from distutils.core import setup

setup(
        name='Subury',
        version='1.0.1',
        py_modules=['Subury_Print_lol'],
        author='Subury',
        author_email='1446849325@qq.com',
        url='http://www.surbury.me',
        description='A simple printer of nested lists',
    )
